ClocksWindow > .frame {
    background-color: mix(@theme_fg_color, @theme_bg_color, 0.95);
    box-shadow: inset 0 5px 2px -6px black;
}

ClocksWindow > .frame:backdrop {
    background-color: mix(@theme_unfocused_fg_color, @theme_unfocused_bg_color, 0.95);
    box-shadow: none;
}

.clocks-tiles-view {
    background-color: transparent;
}

.clocks-digital-renderer {
    background-color: transparent;
}

.clocks-digital-renderer.stripe {
    font-size: 32px;
}

/* world */

.clocks-digital-renderer.light.stripe {
    background-color: rgba(255, 255, 255, 0.4);
    color: black;
}

.clocks-digital-renderer.light.stripe:prelight {
    background-color: rgba(255, 255, 255, 0.6);
}

.clocks-digital-renderer.dark.stripe {
    background-color: rgba(0, 0, 0, 0.4);
    color: white;
}

.clocks-digital-renderer.dark.stripe:prelight {
    background-color: rgba(0, 0, 0, 0.2);
}

/* alarms */

.clocks-digital-renderer.active {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@theme_selected_bg_color,1.2)), to(@theme_selected_bg_color));
    color: white;
}

.clocks-digital-renderer.active:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@theme_selected_bg_color, 1.4)), to(@theme_selected_bg_color));
    text-shadow: 0 2px 2px rgba(0,0,0,0.5)
}

.clocks-digital-renderer.snoozing {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(@warning_color), to(shade(@warning_color,0.9)));
    color: white;
}

.clocks-digital-renderer.snoozing:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@warning_color,1.1)), to(shade(@warning_color,0.99)));
    text-shadow: 0 2px 2px rgba(0,0,0,0.5)
}

.clocks-digital-renderer.inactive {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@insensitive_bg_color,0.9)), to(shade(@insensitive_bg_color,0.85)));
    color: shade(@insensitive_fg_color,0.9);
}

.clocks-digital-renderer.inactive:prelight {
    background-color: transparent;
    background-image: -gtk-gradient(radial,
                                    center center, 0,
                                    center bottom, 1.0,
                                    from(shade(@insensitive_bg_color,0.99)), to(shade(@insensitive_bg_color,0.9)));
    color: @insensitive_fg_color;
}

.clocks-ampm-toggle-button {
    font-size: 18px;
}

.clocks-digital-renderer.active.stripe,
.clocks-digital-renderer.snoozing.stripe,
.clocks-digital-renderer.inactive.stripe {
    background-color: transparent;
    background-image: none;
}

.clocks-standalone-label,
.clocks-ringing-label {
    font-size: 64px;
}

.clocks-secondary-standalone-label {
    font-size: 18px;
}

.clocks-button {
    font-size: 14px;
}

.clocks-alarm-setup-time {
    font-size: 32px;
}

.clocks-spinbutton {
    font-size: 48px;
}

.clocks-stopwatch-label,
.clocks-timer-label {
    font-size: 48px;
}

.clocks-analog-frame.trough {
    color: mix(@theme_fg_color, @theme_bg_color, 0.85);
}

.clocks-analog-frame.progress {
    color: mix(@theme_fg_color, @theme_bg_color, 0.5);
}

.clocks-analog-frame.progress-fast {
    color: @theme_fg_color;
}

.clocks-laps-panel {
    border: 0;
}

.clocks-laps-panel > .frame:dir(ltr) {
    border-image: linear-gradient(to bottom,
                                  mix(@borders,@theme_bg_color,0.5))
                  0 0 0 1 / 20px 0px 20px 1px stretch;
}

.clocks-laps-panel > .frame:dir(rtl) {
    border-image: linear-gradient(to bottom,
                                  mix(@borders,@theme_bg_color,0.5))
                  0 1 0 0 / 20px 1px 20px 0px stretch;
}

.clocks-laps-panel .list,
.clocks-laps-panel .list-row {
    background-color: transparent;
}

.clocks-laps-panel .list-row {
    padding-left: 20px;
    padding-right: 20px;
    font-size: 14px;
    border-image: linear-gradient(to bottom,
                                  mix(@borders,@theme_bg_color,0.5))
                  0 0 1 0 / 0 20px 1px 20px stretch;
}

.clocks-laps-panel .first-lap-row {
    border-image: none;
    border-color: transparent;
}

.clocks-laps-panel .lap-time {
    font-weight: bold;
    padding-right: 20px;
}

/* disguise insensitive spinbuttons as normal labels */
.spinbutton.clocks-timer-label,
.spinbutton.clocks-timer-label .button {
    border-color: transparent;
    background-image: none;
    box-shadow: none;
}

.spinbutton.clocks-timer-label {
    color: @theme_fg_color;
}

.spinbutton.clocks-timer-label .button {
    color: transparent;
}

@keyframes clocks-blink {
    0% { color: @theme_fg_color; }
    100% { color: @insensitive_fg_color; }
}

.clocks-paused .clocks-timer-label {
    animation-name: clocks-blink;
    animation-iteration-count: infinite;  
    animation-timing-function: cubic-bezier(1.0,0,0,1.0);
    animation-duration: 1s; 
}

